==> radicl-0.2.2.tar.gz: radicl-0.2.2/radicl/cli.py <==
import os
from radicl.radicl import RADICL
from radicl.ui_tools import Messages
debug = False

# Get the screen outputter
out=Messages()


logo = """\
██████╗  █████╗ ██████╗
██╔══██╗██╔══██╗██╔══██╗
██████╔╝███████║██║  ██║
██╔══██╗██╔══██║██║  ██║
██║  ██║██║  ██║██████╔╝
╚═╝  ╚═╝╚═╝  ╚═╝╚═════╝

 ██████╗ ██████╗ ███╗   ███╗███╗   ███╗ █████╗ ███╗   ██╗██████╗
██╔════╝██╔═══██╗████╗ ████║████╗ ████║██╔══██╗████╗  ██║██╔══██╗
██║     ██║   ██║██╔████╔██║██╔████╔██║███████║██╔██╗ ██║██║  ██║
██║     ██║   ██║██║╚██╔╝██║██║╚██╔╝██║██╔══██║██║╚██╗██║██║  ██║
╚██████╗╚██████╔╝██║ ╚═╝ ██║██║ ╚═╝ ██║██║  ██║██║ ╚████║██████╔╝
 ╚═════╝ ╚═════╝ ╚═╝     ╚═╝╚═╝     ╚═╝╚═╝  ╚═╝╚═╝  ╚═══╝╚═════╝

██╗     ██╗███╗   ██╗███████╗
██║     ██║████╗  ██║██╔════╝
██║     ██║██╔██╗ ██║█████╗
██║     ██║██║╚██╗██║██╔══╝
███████╗██║██║ ╚████║███████╗
╚══════╝╚═╝╚═╝  ╚═══╝╚══════╝

██╗███╗   ██╗████████╗███████╗██████╗ ███████╗ █████╗  ██████╗███████╗
██║████╗  ██║╚══██╔══╝██╔════╝██╔══██╗██╔════╝██╔══██╗██╔════╝██╔════╝
██║██╔██╗ ██║   ██║   █████╗  ██████╔╝█████╗  ███████║██║     █████╗
██║██║╚██╗██║   ██║   ██╔══╝  ██╔══██╗██╔══╝  ██╔══██║██║     ██╔══╝
██║██║ ╚████║   ██║   ███████╗██║  ██║██║     ██║  ██║╚██████╗███████╗
╚═╝╚═╝  ╚═══╝   ╚═╝   ╚══════╝╚═╝  ╚═╝╚═╝     ╚═╝  ╚═╝ ╚═════╝╚══════╝
"""

def main():
    #Clear the screen in console
    if 'nt' in os.name:
        os.system('cls')  # for Windows
    else:
        os.system('clear')  # for Linux/OS X

    out.msg("")
    out.msg(logo)

    #Information
    out.headline("\nWELCOME TO THE LYTE PROBE CLI")
    out.warn("\n\tWarning: This CLI is not meant to run with the mobile app."
            "\n\tPlease make sure your RAD app is closed out.")
    out.msg("\nThings you can do with this tool:\n",'header')
    out.msg("\t* Plot various data from the probe."+
            "\n\t* Write various data to a file. (In development)"+
            "\n\t* Modify probe settings.  (In development)"+
            "\n\t* Update the firmware (In development)\n")

    # try:
    cli = RADICL()
    cli.run()


if __name__ == '__main__':
    main()

==> radicl-0.4.2.tar.gz: radicl-0.4.2/radicl/cli.py <==
# coding: utf-8

import argparse
import os

from radicl import __version__
from radicl.radicl import RADICL
from radicl.ui_tools import Messages

debug = False

# Get the screen outputter
out = Messages()


logo = """\
██████╗  █████╗ ██████╗
██╔══██╗██╔══██╗██╔══██╗
██████╔╝███████║██║  ██║
██╔══██╗██╔══██║██║  ██║
██║  ██║██║  ██║██████╔╝
╚═╝  ╚═╝╚═╝  ╚═╝╚═════╝

 ██████╗ ██████╗ ███╗   ███╗███╗   ███╗ █████╗ ███╗   ██╗██████╗
██╔════╝██╔═══██╗████╗ ████║████╗ ████║██╔══██╗████╗  ██║██╔══██╗
██║     ██║   ██║██╔████╔██║██╔████╔██║███████║██╔██╗ ██║██║  ██║
██║     ██║   ██║██║╚██╔╝██║██║╚██╔╝██║██╔══██║██║╚██╗██║██║  ██║
╚██████╗╚██████╔╝██║ ╚═╝ ██║██║ ╚═╝ ██║██║  ██║██║ ╚████║██████╔╝
 ╚═════╝ ╚═════╝ ╚═╝     ╚═╝╚═╝     ╚═╝╚═╝  ╚═╝╚═╝  ╚═══╝╚═════╝

██╗     ██╗███╗   ██╗███████╗
██║     ██║████╗  ██║██╔════╝
██║     ██║██╔██╗ ██║█████╗
██║     ██║██║╚██╗██║██╔══╝
███████╗██║██║ ╚████║███████╗
╚══════╝╚═╝╚═╝  ╚═══╝╚══════╝

██╗███╗   ██╗████████╗███████╗██████╗ ███████╗ █████╗  ██████╗███████╗
██║████╗  ██║╚══██╔══╝██╔════╝██╔══██╗██╔════╝██╔══██╗██╔════╝██╔════╝
██║██╔██╗ ██║   ██║   █████╗  ██████╔╝█████╗  ███████║██║     █████╗
██║██║╚██╗██║   ██║   ██╔══╝  ██╔══██╗██╔══╝  ██╔══██║██║     ██╔══╝
██║██║ ╚████║   ██║   ███████╗██║  ██║██║     ██║  ██║╚██████╗███████╗
╚═╝╚═╝  ╚═══╝   ╚═╝   ╚══════╝╚═╝  ╚═╝╚═╝     ╚═╝  ╚═╝ ╚═════╝╚══════╝
"""


def main():
    parser = argparse.ArgumentParser(
        description="CLI script for live interactions with the Lyte probe.")
    parser.add_argument('--version', action='version',
                        version=('%(prog)s {version}'
                                 '').format(version=__version__))
    args = parser.parse_args()

    # Clear the screen in console
    if 'nt' in os.name:
        os.system('cls')  # for Windows
    else:
        os.system('clear')  # for Linux/OS X

    out.msg("")
    out.msg(logo)

    # Information
    out.headline("\nWELCOME TO THE LYTE PROBE CLI")
    out.warn("\n\tWarning: This CLI is not meant to run with the mobile app."
             "\n\tPlease make sure your RAD app is closed out.")
    out.msg("\nThings you can do with this tool:\n", 'header')
    out.msg("\t* Plot various data from the probe." +
            "\n\t* Write various data to a file. (In development)" +
            "\n\t* Modify probe settings.  (In development)" +
            "\n\t* Update the firmware (In development)\n")

    # try:
    cli = RADICL()
    cli.run()


if __name__ == '__main__':
    main()
